==> wormux_0.7.orig.tar.gz: wormux-0.7/src/gui/check_box.h <==
/******************************************************************************
 *  Wormux, a free clone of the game Worms from Team17.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Checkbox in GUI.
 *****************************************************************************/

#ifndef CHECK_BOX_H
#define CHECK_BOX_H

#include "../include/base.h"
#include "../graphic/text.h"
#include "../gui/widget.h"
#include "../graphic/sprite.h"
#include <string>

class CheckBox : public Widget
{
 private:
  Text *txt_label;
  bool m_value;
  Sprite *m_image;
   
 public:
  CheckBox(const std::string &label, const Rectanglei &rect, bool value = true);
  ~CheckBox();
  void Draw(const Point2i &mousePosition) ;
  bool Clic(const Point2i &mousePosition, uint button) ;
  void SetSizePosition(const Rectanglei &rect);

  bool GetValue() const;
  void SetValue(bool value);
};

#endif

==> wormux_0.7.9.orig.tar.gz: wormux-0.7.9/src/gui/check_box.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2004 Lawrence Azzoug.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Checkbox in GUI.
 *****************************************************************************/

#ifndef CHECK_BOX_H
#define CHECK_BOX_H

#include "../include/base.h"
#include "../graphic/text.h"
#include "../gui/widget.h"
#include "../graphic/sprite.h"
#include <string>

class CheckBox : public Widget
{
 protected:
  Text *txt_label;
  bool m_value;
  Sprite *m_checked_image;
  bool hidden;
   
 public:
  CheckBox(const std::string &label, const Rectanglei &rect, bool value = true);
  ~CheckBox();
  void Draw(const Point2i &mousePosition, Surface& surf) const;
  Widget* Clic(const Point2i &mousePosition, uint button) ;
  void SetSizePosition(const Rectanglei &rect);

  bool GetValue() const;
  void SetValue(bool value);

  void SetVisible(bool visible);
};

#endif
